ete2.coretype.tree

Package ete2 :: Package coretype :: Module tree |
[hide private]
[frames] | no frames]

# Module tree

source code

Classes | [hide private]
| TreeError Exception class designed for tree.
| TreeNode TreeNode (Tree) class is used to store a tree structure.
| Tree TreeNode (Tree) class is used to store a tree structure.

Functions | [hide private]
_translate_nodes(root, *nodes) | source code
asETE(R_phylo_tree) | source code
asRphylo(ETE_tree) | source code

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev90``'``
| DEFAULT_COMPACT = `False`
| DEFAULT_SHOWINTERNAL = `False`
| __package__ = ``'``ete2.coretype``'``